pub fn get_avg_px_for_quantity(
qty: Quantity,
levels: &BTreeMap<BookPrice, BookLevel>,
) -> f64Expand description
Calculates the estimated average price for a specified quantity from a set of order book levels.
Panics
Panics if the calculated average price cannot be parsed as an f64.