get_quantity_for_price

Function get_quantity_for_price 

pub fn get_quantity_for_price(
    price: Price,
    order_side: OrderSideSpecified,
    levels: &BTreeMap<BookPrice, BookLevel>,
) -> f64
Calculates the estimated fill quantity for a specified price from a set of order book levels and order side.