pub fn get_quantity_for_price(
price: Price,
order_side: OrderSideSpecified,
levels: &BTreeMap<BookPrice, BookLevel>,
) -> f64Expand description
Calculates the estimated fill quantity for a specified price from a set of order book levels and order side.